;; Generated package description from zones.el  -*- no-byte-compile: t -*-
(define-package "zones" "2019.7.13.0.20190715.154250" "Zones of text - like multiple regions" 'nil :authors '(("Drew Adams")) :maintainer '("Drew Adams" . "drew.adams@oracle.com") :keywords '("narrow" "restriction" "widen" "region" "zone") :url "https://elpa.gnu.org/packages/zones.html")
